==> xmule-1.8.4.tar.bz2: xmule-1.8.4/src/CommentDialog.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef COMMENTDLG_H

#include <wx/dialog.h>
#include <wx/choice.h>

#include "resource.h"
#include "wintypes.h"

class CKnownFile;
class wxComboBox;

// CCommentDialog dialog 

class CCommentDialog : public wxDialog
{ 
  //DECLARE_DYNAMIC(CCommentDialog) 

public: 
   CCommentDialog(wxWindow* pParent,CKnownFile* file);   // standard constructor 
   virtual ~CCommentDialog(); 
   void Localize(); 
   virtual BOOL OnInitDialog(); 

    

// Dialog Data 
   enum { IDD = IDD_COMMENT }; 
protected: 
   //virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support 
   //DECLARE_MESSAGE_MAP() 
   DECLARE_EVENT_TABLE()
public: 
   void OnBnClickedApply(wxEvent& evt); 
   void OnBnClickedCancel(wxEvent& evt); 
private: 
   //CComboBox   ratebox;//For rate 
   wxComboBox* ratebox;
   CKnownFile* m_file; 
}; 

#endif

==> xmule-1.9.0.tar.bz2: xmule-1.9.0/src/CommentDialog.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef COMMENTDLG_H
#define COMMENTDLG_H

#include <wx/dialog.h>                  // Needed for wxDialog

#include "resource.h"                   // Needed for IDS_PW_APPLY
#include "wintypes.h"                   // Needed for BOOL

class CKnownFile;
class wxComboBox;

class CCommentDialog : public wxDialog
{ 
  //DECLARE_DYNAMIC(CCommentDialog) 

public: 
   CCommentDialog(wxWindow* pParent,CKnownFile* file);   // standard constructor 
   virtual ~CCommentDialog(); 
   void Localize(); 
   virtual BOOL OnInitDialog(); 

    

// Dialog Data 
    enum
    {
        IDD_COMMENT,
        IDD = IDD_COMMENT
    };
protected: 
   //virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support 
   //DECLARE_MESSAGE_MAP() 
   DECLARE_EVENT_TABLE()
public: 
   void OnBnClickedApply(wxEvent& evt); 
   void OnBnClickedCancel(wxEvent& evt); 
private: 
   //CComboBox   ratebox;//For rate 
   wxComboBox* ratebox;
   CKnownFile* m_file; 
}; 

#endif
